diff --git a/README.md b/README.md
index ee24c47..f52f1ff 100644
--- a/README.md
+++ b/README.md
@@ -28,7 +28,7 @@ This Dashboard Power Toy provides:
* Statistics about customer accounts in your store:
* New customers in last X hours
* Total number of customer accounts
- * Customer accounts pending confirmation
+ * Customer accounts confirmed confirmation
* Online users (guest & logged in)
## Screenshots
@@ -105,80 +105,86 @@ The code is licensed under the [MIT License (MIT)](https://github.com/JaJuMa/pot
Developing the Power Toys module and the toys was a lot easier and more fun thanks to [Magewire](https://github.com/magewirephp/magewire).
A big shout and Thank You to [Willem Poortman](https://github.com/wpoortman) for creating Magewire
-## Other [Magento 2 Extensions](ttps://www.jajuma.de/en/jajuma-develop/magento-extensions) by [JaJuMa](https://www.jajuma.de/)
+## Other [Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions) & [Hyvä Themes Extensions](https://www.jajuma.de/en/jajuma-develop/hyva-extensions) by [JaJuMa](https://www.jajuma.de/)
-* :framed_picture: Performance & UX:
[Ultimate Image Optimizer for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/ultimate-image-optimizer-extension-for-magento-2)
+* :framed_picture: Performance & UX:
[Ultimate Image Optimizer for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/ultimate-image-optimizer-extension-for-magento-2)
AVIF & WebP Images, Lazy Loading, High-Resolution / Retina images
-* :framed_picture: Performance & UX:
[WebP Optimized Images for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/webp-optimized-images-extension-for-magento-2#portfolio-content)
+* :framed_picture: Performance & UX:
[WebP Optimized Images for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/webp-optimized-images-extension-for-magento-2#portfolio-content)
The #1 WebP Images Solution for Magento 2
-* :see_no_evil: SEO:
[PRG Pattern Link Masking for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/prg-pattern-link-masking-for-magento-2)
+* :see_no_evil: SEO:
[PRG Pattern Link Masking for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/prg-pattern-link-masking-for-magento-2)
Link Masking for Layered Navigation
-* :cop: User Experience:
[Shariff Social Share for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/shariff-social-share-buttons-extension-for-magento-2)
+* :cop: User Experience:
[Shariff Social Share for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/shariff-social-share-buttons-extension-for-magento-2)
GDPR compliant and customizable Sharing Buttons
-* :movie_camera: Content Management:
[Video Widget for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/video-widget-gdpr-extension-for-magento-2)
+* :movie_camera: Content Management:
[Video Widget for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/video-widget-gdpr-extension-for-magento-2)
Embedding YouTube videos, GDPR compliant with auto preview image & fully responsive
-* :rocket: Performance & UX:
[Page Preload for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/page-preload-extension-for-magento-2)
- Faster page transitions and subsequent page-loads by preloading / prefetching
+* :rocket: Performance & UX:
[Page Preload for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/page-preload-extension-for-magento-2)
+ Faster faster page transitions and subsequent page-loads by preloading / prefetching
-* :chart_with_upwards_trend: Marketing:
[Matomo Analytics for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/honey-spam-anti-spam-extension-for-magento-2)
+* :chart_with_upwards_trend: Marketing:
[Matomo Analytics for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/honey-spam-anti-spam-extension-for-magento-2)
Web Analytics - GDPR Compliant
-* :honey_pot: Site Optimization:
[Honey Spam Anti-Spam for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/honey-spam-anti-spam-extension-for-magento-2)
+* :honey_pot: Site Optimization:
[Honey Spam Anti-Spam for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/honey-spam-anti-spam-extension-for-magento-2)
Spam Protection - Reliable & GDPR Compliant
-* :bell: Marketing:
[Customer Registration Reminder & Cleanup for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/customer-registration-reminder-and-cleanup-extension-for-magento-2)
+* :bell: Marketing:
[Customer Registration Reminder & Cleanup for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/customer-registration-reminder-and-cleanup-extension-for-magento-2)
Increase Your Customer Engangement & Cleanup your Customer Account Data Automatically
-* :mega: UX & Marketing:
[Category Grid Callouts for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/category-grid-callouts-extension-for-magento-2)
+* :mega: UX & Marketing:
[Category Grid Callouts for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/category-grid-callouts-extension-for-magento-2)
Enrich Your Category Grids With Eye-Catching Callouts
-* :thought_balloon: UX & Marketing:
[Customer Satisfaction Feedback for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/category-grid-callouts-extension-for-magento-2)
+* :thought_balloon: UX & Marketing:
[Customer Satisfaction Feedback for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/category-grid-callouts-extension-for-magento-2)
Collect Valuable Feedback From Your Customers & Understand How To Satisfy Your Customers
-* :sparkler: UX:
[Auto Select Options for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/auto-select-options-extension-for-magento-2)
+* :sparkler: UX:
[Auto Select Options for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/auto-select-options-extension-for-magento-2)
Automatically Select Configurable & Custom Options Based On Your Customer's Preferences
-* :left_right_arrow: UX & Performance:
[Back Forward Cache - bfcache for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/back-forward-cache-extension-for-magento-2)
+* :left_right_arrow: UX & Performance:
[Back Forward Cache - bfcache for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/back-forward-cache-extension-for-magento-2)
Enable bfcache for Magento 2 for improved UX & Core Web Vitals
-* :heavy_division_sign: Accounting:
[Dynamic Shipping Tax Plus for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/proportional-pro-rata-dynamic-shipping-tax-plus-extension-for-magento-2)
+* :heavy_division_sign: Accounting:
[Dynamic Shipping Tax Plus for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/proportional-pro-rata-dynamic-shipping-tax-plus-extension-for-magento-2)
Dynamic Shipping Tax Calculation incl. pro-rata/proportional tax rates
-* :mag: Search:
[MySQL Search for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/magento-without-elasticsearch-mysql-search-extension-for-magento-2)
+* :mag: Search:
[MySQL Search for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/magento-without-elasticsearch-mysql-search-extension-for-magento-2)
MySQL Search for Magento 2 without Elasticsearch
-* :bangbang: Performance:
[Preload Critical Resources & Assets](https://www.jajuma.de/en/jajuma-develop/extensions/resource-hints-preload-critical-resources-assets-extension-for-magento-2)
+* :bangbang: Performance:
[Preload Critical Resources & Assets](https://www.jajuma.de/en/jajuma-develop/magento-extensions/resource-hints-preload-critical-resources-assets-extension-for-magento-2)
Resource Hints for preloading important and critical resources
-* :octocat: Content Management:
[git 4 Page Builder](https://www.jajuma.de/en/jajuma-develop/extensions/git-4-page-builder-extension-for-magento-2)
+* :octocat: Content Management:
[git 4 Page Builder](https://www.jajuma.de/en/jajuma-develop/magento-extensions/git-4-page-builder-extension-for-magento-2)
Manage & deploy Magento 2 Page Builder content via git
-* :rocket: Performance:
[Hyvä Inline CSS](https://www.jajuma.de/en/jajuma-develop/extensions/hyva-inline-css-extension-for-magento-with-hyva-themes)
+* :rocket: Performance:
[Hyvä Inline CSS](https://www.jajuma.de/en/jajuma-develop/magento-extensions/hyva-inline-css-extension-for-magento-with-hyva-themes)
Run Magento 2 without CSS file by inline all CSS
-* :man_technologist: :free: Content Management:
[Syntax Highlighter 4 Page Builder](https://www.jajuma.de/en/jajuma-develop/extensions/syntax-highlighter-4-page-builder-extension-for-magento-2)
+* :zap: Performance:
[Smart Speculations Rules](https://www.jajuma.de/en/jajuma-develop/magento-extensions/smart-speculations-rules-extension-for-magento-2)
+ Instant Page Navigations With Smart Data-Driven Prerendering Via Speculations Rules API
+
+* :man_technologist: :free: Content Management:
[Syntax Highlighter 4 Page Builder](https://www.jajuma.de/en/jajuma-develop/magento-extensions/syntax-highlighter-4-page-builder-extension-for-magento-2)
Syntax Highlighting and more for Magento 2 Page Builder
-* :triangular_flag_on_post: :free: UI & UX:
[Awesome Hyvä for Hyvä Themes](https://www.jajuma.de/en/jajuma-develop/extensions/font-awesome-icons-for-hyva-themes-extension)
+* :triangular_flag_on_post: :free: UI & UX:
[Awesome Hyvä for Hyvä Themes](https://www.jajuma.de/en/jajuma-develop/magento-extensions/font-awesome-icons-for-hyva-themes-extension)
Font Awesome 5 & 6 Icons for your [Hyvä Themes](https://www.jajuma.de/de/jajuma-shop/online-shop-mit-magento-2-und-hyva-themes) Store
-* :triangular_flag_on_post: :free: UI & UX:
[Hyvä Flags for Hyvä Themes](https://www.jajuma.de/en/jajuma-develop/extensions/country-language-flag-icons-for-hyva-themes-extension)
+* :triangular_flag_on_post: :free: UI & UX:
[Hyvä Flags for Hyvä Themes](https://www.jajuma.de/en/jajuma-develop/magento-extensions/country-language-flag-icons-for-hyva-themes-extension)
Country & Language Flag Icons for your [Hyvä Themes](https://www.jajuma.de/de/jajuma-shop/online-shop-mit-magento-2-und-hyva-themes) Store
-* :ok_man: :free: User Experience:
[Customer Navigation Manager for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/customer-navigation-manager-extension-for-magento-2)
+* :ok_man: :free: User Experience:
[Customer Navigation Manager for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/customer-navigation-manager-extension-for-magento-2)
Easily manage the links in your Customer Account
-* :heavy_division_sign: :free: Accounting:
[Dynamic Shipping Tax for Magento 2](https://www.jajuma.de/en/jajuma-develop/extensions/dynamic-shipping-tax-extension-for-magento-2)
+* :heavy_division_sign: :free: Accounting:
[Dynamic Shipping Tax for Magento 2](https://www.jajuma.de/en/jajuma-develop/magento-extensions/dynamic-shipping-tax-extension-for-magento-2)
Dynamic Shipping Tax Calculation
-* :question: :free: Content:
[Hyvä FAQ Widget for Hyvä Themes](https://www.jajuma.de/en/jajuma-develop/extensions/dynamic-shipping-tax-extension-for-magento-2)
+* :question: :free: Content:
[Hyvä FAQ Widget for Hyvä Themes](https://www.jajuma.de/en/jajuma-develop/magento-extensions/hyva-faq-widget-extension-for-hyva-themes)
FAQ Widget for your [Hyvä Themes](https://www.jajuma.de/de/jajuma-shop/online-shop-mit-magento-2-und-hyva-themes) Store
+* :jigsaw: :free: Admin Tools:
[Magento Power Toys](https://www.jajuma.de/en/jajuma-develop/magento-extensions/power-toys-for-magento-2)
+ Tools and helpers, a.k.a "Toys", for Magento Admins
+
## Other [Services](https://www.jajuma.de/en/jajuma/company-magento-ecommerce-agency-stuttgart) by [JaJuMa](https://www.jajuma.de/)
* :shopping: [JaJuMa-Market: Marketplace Software](https://www.jajuma.de/en/jajuma-market)
diff --git a/composer.json b/composer.json
index f8d21f9..2dfe710 100644
--- a/composer.json
+++ b/composer.json
@@ -3,7 +3,7 @@
"description": "Customers Power Toy for Magento 2 by JaJuMa",
"type": "magento2-module",
"license": "MIT",
- "version": "1.0.0",
+ "version": "1.0.2",
"authors": [
{
"email": "info@jajuma.de",
@@ -14,7 +14,7 @@
"require": {
"magewirephp/magewire": "^1.10",
"magewirephp/magewire-requirejs": "^1.1",
- "jajuma/power-toys": "^1.0"
+ "jajuma/power-toys": "^1.0.3"
},
"autoload": {
"psr-4": {
diff --git a/view/base/templates/customers.phtml b/view/base/templates/customers.phtml
index 33960ef..74e5627 100644
--- a/view/base/templates/customers.phtml
+++ b/view/base/templates/customers.phtml
@@ -9,7 +9,7 @@ use Jajuma\PotCustomers\Block\Customers;
$lastXHours = $block->getLastXHours();
$numberNewCustomers = number_format($block->getNumberNewCustomers(), 0, '', '.');
$totalCustomers = number_format($block->getTotalCustomers(), 0, '', '.');
-$pendingCustomers = number_format($block->getPendingCustomers(), 0, '', '.');
+$confirmedCustomers = number_format($block->getConfirmedCustomers(), 0, '', '.');
$customersOnline = number_format($block->getCustomersOnline(), 0, '', '.');
$guestsOnline = number_format($block->getGuestsOnline(), 0, '', '.');
?>
@@ -25,9 +25,9 @@ $guestsOnline = number_format($block->getGuestsOnline(), 0, '', '.');
= $totalCustomers ?>
-
diff --git a/Block/Customers.php b/Block/Customers.php
index 5d87e64..05b1201 100644
--- a/Block/Customers.php
+++ b/Block/Customers.php
@@ -103,17 +103,17 @@ public function getTotalCustomers()
}
/**
* Get pending customers
*
* @return mixed
*/
- public function getPendingCustomers()
+ public function getConfirmedCustomers()
{
$isCustomerConfirmationRequired = $this->helperConfig->isCustomerConfirmationRequired();
if ($isCustomerConfirmationRequired) {
- $pendingCollection = $this->customerFactory->create()
+ $confirmedCollection = $this->customerFactory->create()
->getCollection()->addFieldToFilter('confirmation', ['null' => true]);
- return $pendingCollection->getSize();
+ return $confirmedCollection->getSize();
}
return 0;
}
@@ -103,17 +103,17 @@ public function getTotalCustomers()
}
/**
- * Get pending customers
+ * Get confirmed customers
*
* @return mixed